#
# spec file for package mousepad
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libmousepad0
Name:           mousepad
Version:        0.6.1
Release:        1.2
Summary:        Simple Text Editor for Xfce
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://docs.xfce.org/apps/mousepad/start
Source:         https://archive.xfce.org/src/apps/mousepad/0.6/mousepad-%{version}.tar.bz2
BuildRequires:  appstream-glib
BuildRequires:  gettext >= 0.19.8
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.2
BuildRequires:  pkgconfig(gmodule-2.0)  >= 2.56.2
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtksourceview-4) >= 4.0.0
BuildRequires:  pkgconfig(libxfconf-0)

%description
Mousepad is a simple text editor for Xfce.

%package -n %{libname}
Summary:        Mousepad plugin provider
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n %{libname}
A plugin provider for the Mousepad text editor

%package devel
Summary:        Development files for Mousepad
Group:          Development/Libraries
Requires:       %{libname} >= %{version}

%Description devel
Development files for Mousepad plugin development

%lang_package

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%find_lang %{name} %{?no_lang_C}

%suse_update_desktop_file org.xfce.%{name}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc AUTHORS NEWS ChangeLog README.md
%license COPYING
%{_bindir}/mousepad
%{_datadir}/applications/org.xfce.mousepad.desktop
%{_datadir}/applications/org.xfce.mousepad-settings.desktop
%{_datadir}/glib-2.0/schemas/org.xfce.mousepad.gschema.xml
%{_datadir}/glib-2.0/schemas/org.xfce.mousepad.plugins.gspell.gschema.xml
%{_datadir}/metainfo/org.xfce.%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/org.xfce.mousepad.*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/libmousepad-plugin-gspell.so

%files -n %{libname}
%{_libdir}/libmousepad.so.*

%files devel
%{_libdir}/libmousepad.so

%files lang -f %{name}.lang

%changelog
* Sat May 13 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.6.1
  * I18n: Update po/LINGUAS list
  * build: Optionally require polkit
  * build: Use m4_defined min versions and cleanup
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Switch from intltool to gettext
  * menubar: Improve some strings
  * search: Use consistent naming
  * history: Properly restore multi-window session
  * Restore opening mode only when it was overridden from the command
    line
  * Add "X of Y matches" to search bar and replace dialog (Closes #174)
  * Add application/x-zerosize to supported mime types (Fixes #194)
  * Apply opening mode also to the open dialog (Fixes #181)
  * Properly reconnect signal handler when auto-reload is enabled
  * Translation Updates
* Thu Feb  9 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.6.0
  * Dependency Changes:
  - GLib >= 2.56.2
  * New Features:
  - Keep saved state in memory to track actual modification state
  * Appearance Changes / Minor Improvements:
  - Add "match whole word" toggle to search toolbar (#180, !124)
  * Code Refactoring:
  - cleanup: prefs: Reduce the diff from what Glade 3.40.0 would do
  - cleanup: Use G_DECLARE_FINAL_TYPE
  - cleanup: Remove dead code
  - cleanup: Use consistent naming and avoid duplicated code
  - build: Let xdt-depends.m4 macros set GLib macros
  - flatpak: Updates from Flathub
  * Bug Fixes:
  - Clear undo action list in case of unbuffered modification
  - Set file properties only for actual changes
  - Emit "encoding-changed" after setting BOM if needed
  - Update action states on reload
  - Mark document as modified if line ending actually changes (Fixes #187)
  - Do not show the menubar on Alt key release if focus is lost (#185)
  - plugins: Do not resize unnecessarily the prefs dialog on Wayland
  - Initialize static variable only once
  - prefs-dialog: Improve history widget alignment (Fixes #173)
  * Translation Updates
* Sun Jul 10 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.10
  * Consider unnamed files unchanged when empty
    (gxo#apps/mousepad#170, gxo#apps/mousepad!123)
  * session-restore: Manage autosave ids through a GList
    (gxo#apps/mousepad#165)
  * Honor global "gtk-menu-images" setting for icon visibility
  * search: Do not select first combo box entry when list does not
    change
  * Fix encoding conversion when saving
  * Fix encoding conversion when opening (gxo#apps/mousepad#172)
  * Update charset when a byte order mark is detected
    (gxo#apps/mousepad#172)
  * tests: Add plugin settings to the list
  * build: Fix intltool lock file problem during make distcheck
  * Fix a memory leak in menu item realignment
    (gxo#apps/mousepad#164)
  * Translation Updates
* Sat Apr  2 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.9
  * Add Shortcuts plugin, requires libxfce4ui >= 4.17.5 and as
    such remains disabled at build time until Xfce 4.18 is released
    (gxo#apps/mousepad#70, gxo#apps/mousepad!121)
  * Add search history (gxo#apps/mousepad!119)
  * File monitoring: Add an automatic reloading option
  * Move the document modification mark to the close button
    (gxo#apps/mousepad#63, gxo#apps/mousepad!122)
  * Add mousepad styleclass for easier theming (gxo#apps/mousepad#33)
  * Hide search bar by pressing Esc key even when not focused
  * Search: Escape selection when regex search is enabled
  * Plugins: Add a skeleton plugin to ease writing of new plugins
  * Test plugin: Sanitize memory management of sources
  * Honor GTK_CSD
  * Filter entries from `accels.scm` on non-detailed action name
  * i18n: Check for `bind_textdomain_codeset()`
  * Update Copying (gxo#apps/mousepad#160, gxo#apps/mousepad!120)
  * Session history: Never clear session array on exit
    (gxo#apps/mousepad#162)
  * Fix broken feature "Show menubar temporarily when hidden"
  * Force encoding when reloading
  * Force encoding when it has been explicitly set by the user
  * Do not consider encoding as always user-set in the "Open" dialog
  * Fix antonym of the word "indent" in preferences dialog
    (gxo#apps/mousepad!118)
  * File monitoring: Try to filter out fake deletions
  * Add ellipsis to preferences menu entry (gxo#apps/mousepad!117)
  * Switch all labels to title case in prefs dialog
    (gxo#apps/mousepad!116)
  * Correctly restore font size after zooming when using system font
    (gxo#apps/mousepad#158)
  * Printing: Enable line wrapping by default (gxo#apps/mousepad#156)
  * Fix a warning from GCC static analyzer
  * Search: Do not delay the search when the text changes
  * Translation Updates
* Mon Nov 29 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.8
  * Revert "Chain-up to parent in `mousepad_window_scroll_event()`"
    (gxo#apps/mousepad#150)
  * Search: Fix a memory leak
  * Search: Remove obsolete workaround for the document finalization
  * Drop restrictions on URI scheme
  * Update `POTFILES.in`
  * Printing: Remove the "Page Setup" dialog (gxo#apps/mousepad#148)
  * Flatpak: Complete scripts
  * Flatpak: Access remote locations with GVfs
  * Search: Fix the history cleanup
  * Search: Prevent GTask warnings when replacing text
  * Search: Ensure settings synchronization before searching
  * Fix translation domain in Appdata file
  * flatpak: Update README
  * flatpak: Add generic manifest and basic scripts
  * Translation Updates
* Thu Sep 23 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.7
  * Update Appdata file and use the same description everywhere
  * Prevent warning when saving a deleted file via a symlink
    (gxo#apps/mousepad#135)
  * Conform to Freedesktop.org standard for file naming
  * Properly disconnect signal handlers
  * Be sure not to disable highlighting when disabling regex search
  * Check for realpath()
  * Check for `errno.h` required by CI
  * Fix a nasty memory leak
  * Fix "Save As" procedure when it recurses
  * Allow drag and drop on selections in the textview
  * Code cleanup: Remove a useless dnd signal forwarding
  * Code cleanup: Simplify `mousepad_file_save()`
  * Fix a small memory leak
  * Improve trash can management
  * Update read-only status on file location change/validation
  * Monitor also the target of broken links
  * Fix monitoring of files opened through a symlink
  * Allow drag and drop of broken links
  * Follow symlinks if necessary when checking if a file exists
  * Replace `g_realloc()` with `g_renew()`
  * Replace `g_malloc*()` with `g_new*()` (gxo#apps/mousepad!113)
  * Make sure that `gtk_selection_data_get_uris()` returned non-NULL
    (gxo#apps/mousepad!113)
  * Initialize `contents` and use it to guard `g_file_replace_contents`
    (gxo#apps/mousepad!113)
  * Fix an unlikely memory leak
  * Make CSD consistent with other Xfce windows (gxo#apps/mousepad#145)
  * Translation Updates
* Sat Jul 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.6
  * Add session backup and restore
  * Remember windows and tabs (gxo#apps/mousepad#21,
    gxo#apps/mousepad!108)
  * Handle unsaved documents (gxo#apps/mousepad#32,
    gxo#apps/mousepad!109)
  * DE session support (gxo#apps/mousepad#3, gxo#apps/mousepad!110)
  * Extend the use of recent history (gxo#apps/mousepad!107)
  * Add use of `GtkSourceView:smart-backspace`
    (gxo#apps/mousepad!101)
  * Add a "Move Words" action (gxo#apps/mousepad!100)
  * Add a setting to control tab expansion (gxo#apps/mousepad#100)
  * Prefs dialog: Substitute CSD for status bar visibility
  * Add a "File" tab to the prefs dialog (gxo#apps/mousepad!108)
  * Make search input fields less flickery (gxo#apps/mousepad!104)
  * Allow saving non-existent, empty but named file
    (gxo#apps/mousepad#120, gxo#apps/mousepad!103)
  * Enable "Save" action for read-only documents
    (gxo#apps/mousepad#126, gxo#apps/mousepad!103)
  * Make "Find as you type" an option (gxo#apps/mousepad!102)
  * Reveal hidden setting "indent-on-tab" (gxo#apps/mousepad!101)
  * A review of duplicated view-related actions
    (gxo#apps/mousepad#127)
  * Add a test plugin to monitor application state
    (gxo#apps/mousepad!105)
  * Add a test script for Mousepad (gxo#apps/mousepad!99)
  * Filter notebook click events also on y-coordinate
    (gxo#apps/mousepad#144)
  * Allow to open files from the trash can (gxo#apps/mousepad#141,
    gxo#apps/mousepad!112)
  * Monitor file deletion (gxo#apps/mousepad#140,
    gxo#apps/mousepad!111)
  * Printing: Create config file if it does not exist
  * Check all windows for the file to be opened
  * Fix wrong externally modified document in some situations
  * Plugin support: Properly handle plugin settings
    (gxo#apps/mousepad#136)
  * Direct monitoring of symlink targets
  * Set the state of submenu actions
  * print-dialog: Fix some memory leaks
  * Fix a type inconsistency in the "encoding-changed" signal
  * Always check if the user has explicitly set a filetype
  * Fix monitoring events to listen to
  * Ensure statefull actions exist until their state is recovered
  * Fix GVariant-related memory leaks
  * Do not warn if the plugin directory does not exist
  * Add a sanity check on the window for "Externally Modified"
  * Do not set the style scheme id as translatable
  * Properly update recent menu in case of file deletion
  * CSD: Set the decoration layout for all windows
  * Add a sanity check on file location for monitoring
  * Add "preferences" action to `mousepad.desktop`
    (gxo#apps/mousepad#130)
  * Translation Updates
* Sat May 15 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Split new libraries into subpackages
- Make sure plugins support is enabled
- Switch to GtkSourceView 4
- Added ldconfig scriplets for the new shared libraries
* Fri May 14 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.5.5
  - Add a `.desktop` file to make Mousepad appear in Xfce settings
    (gxo#apps/mousepad!94)
  - Add a command line option to open the prefs dialog
    (gxo#apps/mousepad!94)
  - Plugin support (gxo#apps/mousepad!92)
  - Add gspell plugin (gxo#apps/mousepad#1, gxo#apps/mousepad!92)
  - Disable and wipe recent history if recent-menu-items is set to 0
    (gxo#apps/mousepad#112, gxo#apps/mousepad!89)
  - Support -ve line and column values for "Go to" location
    (gxo#apps/mousepad#113, gxo#apps/mousepad!84)
  - Switch to client-side decorations (gxo#apps/mousepad!97)
  - Remove Xfconf dependency
    (gxo#apps/mousepad#60, gxo#apps/mousepad#122, gxo#apps/mousepad!98)
  - A general review of sanity checks
  - A review of window lifetime management
  - A review of document lifetime management
  - Automate and sanitize memory management of sources
  - A small review of GSettings use
  - Do not use `== (TRUE|FALSE)` for boolean conditions
  - Fix actions to show/hide bars in fullscreen mode
    (gxo#apps/mousepad#129)
  - Fix broken "Revert" action
  - Fix and extend "Move Lines" action
    (gxo#apps/mousepad#87, gxo#apps/mousepad#116, gxo#apps/mousepad!96)
  - Support for drag and drop of tabs when search is active
  - Do a silent search when changing tabs with the search bar enabled
  - Use get/set_real_line_offset () functions for "Paste as Column"
    (gxo#apps/mousepad#114, gxo#apps/mousepad!91)
  - Restore cursor position after transpose
    (gxo#apps/mousepad#115, gxo#apps/mousepad!88)
  - Fix "Delete Line" action
    (gxo#apps/mousepad#117, gxo#apps/mousepad!86)
  - Fix recent_sort function (gxo#apps/mousepad!90)
  - Reset line and column number if not given on command line
    (gxo#apps/mousepad#121, gxo#apps/mousepad!87)
  - menu: "Spaces to Tabs" converter converts leading spaces
    (gxo#apps/mousepad#118, gxo#apps/mousepad!85)
  - Make window require attention when opening new tabs
    (gxo#apps/mousepad#119)
  - Translation Updates
* Sat Apr  3 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.4
  * Add --line/-l and --column/-c number (gxo#apps/mousepad#107,
    gxo#apps/mousepad!83)
  * Port to GtkSourceView 4 (gxo#apps/mousepad#55,
    gxo#apps/mousepad#80, gxo#apps/mousepad!10)
  * Delay request to scroll to cursor for the correct active view
  * Monitor hardlinks with glib 2.56.2 (gxo#apps/mousepad#110,
    gxo#apps/mousepad!82)
  * Transfer encoding from remote to primary instance
    (gxo#apps/mousepad#109)
  * Prevent a crash when no language is found
  * Make window require attention when opening new tabs
    (gxo#apps/mousepad#106, gxo#apps/mousepad#93, gxo#apps/mousepad!81)
  * Fix BOM array (gxo#apps/mousepad!80)
  * Correctly initialize toolbar style combo box (gxo#apps/mousepad#103)
  * Allow checking parent sources when looking up schema
    (gxo#apps/mousepad#101)
  * Fix missing parameter to "select-all" signal (gxo#apps/mousepad!79)
  * Translation Updates
* Sun Feb 28 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.3
  * Use old style menu alignment (gxo#apps/mousepad#97,
    gxo#apps/mousepad!77)
  * Add a keybinding to reset font size
  * Fix inverted return value of scroll event handler
  * Various small improvements regarding accels
  * Block the right signal handler for tooltip updates
  * A clarification about action groups
  * Translation Updates
* Sun Jan 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.2
  * Add a "Viewer Mode" toggle
    (gxo#apps/mousepad#50, gxo#apps/mousepad!72)
  * Improve `--quit` option: close all windows interactively
    (gxo#apps/mousepad!71)
  * Improve encoding management
    (gxo#apps/mousepad#42, gxo#apps/mousepad!69)
  - Display the current encoding in the status bar
  - Make the default encoding configurable via GSettings
  - Allow to choose encoding in the "Open" and "Save As" dialogs
    (gxo#apps/mousepad#42)
  - Add a command line option to choose encoding
  * Add a "Delete Line" action
    (gxo#apps/mousepad#13, gxo#apps/mousepad!66)
  * Make automatic addition of the last EOL character configurable
    (gxo#apps/mousepad#53, gxo#apps/mousepad!65)
  * Switch to GFile for I/O operations (gxo#apps/mousepad#4,
    gxo#apps/mousepad#27, gxo#apps/mousepad#75, gxo#apps/mousepad!64)
  * - Add file monitoring (gxo#apps/mousepad#75)
  * - Add a setting to create a tilde-backup file when saving
    (gxo#apps/mousepad#27)
  * - Make saving atomic (gxo#apps/mousepad#4)
  * Filter files on mime type in the "Open" and "Save As" dialogs
    (gxo#apps/mousepad#2, gxo#apps/mousepad#35, gxo#apps/mousepad!67)
  * Improve encoding management
    (gxo#apps/mousepad#42, gxo#apps/mousepad!69)
  - Make encoding dialog more generic and self-contained
  - Encodings definition review
  - Clarify encoding management when opening files
  - Improve unicode BOM management
  * Switch to GFile for I/O operations (gxo#apps/mousepad#4,
    gxo#apps/mousepad#27, gxo#apps/mousepad#75, gxo#apps/mousepad!64)
  - Set the save action sensitivity more precisely
  - Let GFile APIs check for file existence when reading
  - Let GFile APIs check for external modifications when saving
  - Basic switch to GFile for I/O operations
  * Make "replace" and "replace all" behaviors consistent
  * (gxo#apps/mousepad#94)
  * Ensure that the page setup is properly applied when printing
  * (gxo#apps/mousepad#90)
  * Avoid character escape issues in menu item action names
    (gxo#apps/mousepad#91)
  * Properly initialize document search properties
  * Avoid illegal memory access when searching with tab changes
    (gxo#apps/mousepad!73)
  * Revert to "Wrap Around" always true for the search bar
    (gxo#apps/mousepad#83)
  * Prevent too late accesses to the buffer in selection mode
  * Direct call to keybinding signals for "Delete" and "Select All"
    (gxo#apps/mousepad#83)
  * Improve editing keybindings consistency (gxo#apps/mousepad#83)
  * Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.5.1
  - Dependencies changes: GLib >= 2.52.0 ; GTK >= 3.22.0
  - Allow to change the font size from keyboard/mouse
    (gxo#apps/mousepad#46, gxo#apps/mousepad#54)
  - Switch to asynchronous search
  - Give more choice for whitespace display (gxo#apps/mousepad#44)
  - Improve the look of the search bar
  - Add a spinner to the search widgets
  - Make the occurrences count appear in the search bar
  - Reformulate "Home/End Keys" setting description
  - Code refactoring around MousepadView properties
  - Code refactoring around GMenuModel-bindings
  - Decrease reference count of anchored documents
  - Filter document signals on the active document
  - Fix a memory leak in the templates menu
  - Fix wrong conversion from uri to filename (gxo#apps/mousepad#81)
  - Warn when using GLib functions newer than requirements
  - Translation Updates
* Mon Nov 30 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.5.0
  - Bump required GTK+ in `mousepad-prefs-dialog.ui` (gxo#apps/mousepad#78)
  - Fix an oversight in updating actions state (gxo#apps/mousepad#76)
  - Remove TODO file (gxo#apps/mousepad#74)
  - Ensure that opening modes are excluded from translation
  - Translation Updates
* Fri Nov 20 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.4.90
  * Add keybindings to show the menubar temporarily when hidden
  * Add command line option and setting for file opening mode
  * Improve encoding dialog
  * Add regex search
  * Replace `$HOME` with a tilde in displayed filename
  * Add new default keybindings and reveal some hidden ones
  * Search bar tweaks
  * Make tabs expanded for consistency with other Xfce programs
  * Add copyright and license info to About dialog
  * Improve label texts of "Find and Replace" dialog and search bar
  * Make the statusbar smaller
  * Add new app icon and switch to reverse DNS name
  * Save the state of the "highlight all" button in the search bar
  * Update window title of Find and Replace dialog
  * Add "Wrap around" check box to Find and Replace dialog (bxo#11290)
  * Infer filetype from shebang line (bxo#10514)
  * Show info when Templates directory does not exist (bxo#10486)
  * Restore the use of the file `accels.scm`
  * Code refactoring around saving and restoring window geometry
  * Improve save-related actions
  * Fully switch to GtkApplication
  * Avoid deprecation warnings 5: CSS related
  * Avoid deprecation warnings 4: GtkUIManager and GtkAction
  * GtkStock
  * Avoid deprecation warnings 2: miscellaneous
  * Avoid deprecation warnings 1: alignment and padding
  * Avoid compilation warnings other than deprecation
  * Remove support for GTK+2
  * Switch to README.md and foreign automake mode
  * Add basic GitLab pipeline
  * Remove README.md from DISTCLEANFILES, it's not generated
  * Fix crash when dragging tab to GSV widget
  * Change GtkTextView wrap mode to GTK_WRAP_WORD_CHAR
  * Initialize the recent manager if needed at startup
  * Prevent search bar from overlapping the document
  * Properly disconnect signal handlers
  * Fix make distcheck
  * Fix color modifications in search entries
  * Do not open an empty document when encoding failed
  * Do not search for previously selected text
  * Update search field with selected text
  * bxo#16717: Move from exo-csource to xdt-csource
  * Remember last save location (bxo#14165)
  * Use g_get_user_dir to get Templates directory (bxo#11048)
  * Sync remaining menu actions to their settings (bxo#11046)
  * Install appstream in metainfo folder (bxo#11200)
  * Add appdata file (bxo#11200)
  * Fix building with `--enable-dbus --disable-gtk3`
  * Change visibility of fullscreen bars after small delay (bxo#9735)
  * Fix return type of fullscreen settings (bxo#9735)
  * Translation Updates
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.4.2
  * Port to GDBus (bxo#14337)
  * Show full path in window title by default (bxo#2896)
  * Reset modification time when new filename is set (bxo#10498)
  * Do not overwrite view settings when opening encoding dialog
    (bxo#12298)
  * Make dialog windows modal only for parent window (bxo#10488)
  * Add string to translation (bxo#11049)
  * Selecting a font via menu now disables system font (bxo#12773)
  * Check for exo-csource in maintainer mode (bxo#12719)
  * New line can't be printed in status bar (bxo#11050)
  * Do not move text cursor when searching backwards (bxo#14942)
  * Fix gravity of selection end mark (bxo#10986)
  * Missing line in dbus.h, found typo in window.h (bxo#10583)
  * Append a newline char at EOF when saving (bxo#4824)
  * Do not core dump on silly errors, just exit (bxo#12413)
  * Fix gtksourceview warnings/errors (bxo11663)
  * Only set template filetype when detected (bxo#15314)
  * Replace deprecated style properties in MousepadCloseButton
    (bxo#13114)
  * Fix Tab mode and Home/End Keys in preferences dialog (bxo#15075)
  * Fix language guess function (bxo#15141)
  * Read system font from xfconf property (bxo#12485)
  * Add pkexec policy (bxo#11088)
  * Fix g_type_class_add_private is deprecated
  * Set intltool minimum version
  * Bump minimal required glib
  * Translation updates
* Sat Jun  9 2018 seife+obs@b1-systems.com
- update to version 0.4.1
  - Fix crash when dragging tab to root window (bxo#13336)
  - Fix the signal definition of user-set-language (bxo#13630)
  - Prevent a weird cycle in GSettings use (bxo#12134)
  - Fix some warnings about using NULL (bxo#11663)
  - Limit prefs dialog tab width to range allowed by schema
    (bxo#12055)
  - Don't show hidden GSV languages (bxo#12043)
  - Encode filenames passed to DBus as UTF-8
  - Translation updates
- packaging changes:
  - fix Group: tag
  - build against GTK3
  - use %%license instead of %%doc
* Sat Feb 28 2015 gber@opensuse.org
- update to version 0.4.0
  - Use GSettings to improve preference handling
  - A new preferences dialog exposing all preferences in the GUI
  - Implement config and GUI preferences for various GtkSourceView
    properties such as:
  - Highlighting the current line
  - Match braces
  - Indentation width control
  - Right margin (long-line margin) column
  - Showing/hiding of line numbers
  - Smart home and end keys
  - Improved GUI configurability and state persistence, including:
  - A toolbar for commonly used items
  - Fullscreen support
  - Main menu re-organization
  - Improved editor context menu
  - Improved single-instance multi-window support
  - Remember and synchronize size, position, and state, across
    windows and instances
  - Support for building against GTK+ 3
  - Various other improvements and bugs fixed
- drop obsolete
  mousepad-fix-syntax-highlighting-and-creating-new-file.patch
* Sun May 11 2014 trcs@gmx.com
- add mousepad-fix-syntax-highlighting-and-creating-new-file.patch
  * fix bug https://bugzilla.xfce.org/show_bug.cgi?id=10134
* Sun Dec 30 2012 gber@opensuse.org
- initial packaging of the new development version
